Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorrobocoder <anthon.pang@gmail.com>2010-07-28 06:39:50 +0400
committerrobocoder <anthon.pang@gmail.com>2010-07-28 06:39:50 +0400
commita909dfd1e59e6248fda0280f0a9dbdd77961780f (patch)
tree180dc751479e5dee229f72faa9c00144e08d11bb /core/Updates.php
parent36e36e9a7e44f0d2eaeb92848c14ab055016a583 (diff)
refs #1368 - use schema instead of adapter; in strict mode, update() can't be abstract
git-svn-id: http://dev.piwik.org/svn/trunk@2739 59fd770c-687e-43c8-a1e3-f5a4ff64c105
Diffstat (limited to 'core/Updates.php')
-rw-r--r--core/Updates.php8
1 files changed, 5 insertions, 3 deletions
diff --git a/core/Updates.php b/core/Updates.php
index 3d5e4df537..cea45d94e0 100644
--- a/core/Updates.php
+++ b/core/Updates.php
@@ -21,10 +21,10 @@ abstract class Piwik_Updates
/**
* Return SQL to be executed in this update
*
* @param string Adapter name
* @return array
*/
- static function getSql($adapter = 'PDO_MYSQL')
+ static function getSql($schema = 'Myisam')
{
return array();
}
@@ -32,5 +32,7 @@ abstract class Piwik_Updates
/**
* Incremental version update
*/
- abstract static function update();
+ static function update()
+ {
+ }
}
@@ -21,10 +21,10 @@ abstract class Piwik_Updates
* Return SQL to be executed in this update
*
- * @param string Adapter name
+ * @param string Schema name
* @return array
*/